print("import: 'regex'")
import regex

print("import: 'regex.regex'")
import regex.regex

print("import: 'regex._regex_core'")
import regex._regex_core

print("import: 'regex.test_regex'")
import regex.test_regex

